--------------------------------------------------------------------------------
-- Module Declaration
--

local mod = BigWigs:NewBoss("Horridon Marker", 930)
if not mod then return end
mod:RegisterEnableMob(68476, 69374)

local counter = 1
local adds = {}

local mobs = {
	[69164] = true, --Gurubashi Venom Priest
	[69175] = true, --Farraki Wastewalker
	[69178] = true, --Drakkari Frozen Warlord
	[69177] = true, --Amani Warbear
	[69176] = true, --Amani'shi Beast Shaman
}

--------------------------------------------------------------------------------
-- Localization
--

local mainMod = BigWigs.modules.Bosses.modules["Horridon"]
local L = mainMod:GetLocale()

--------------------------------------------------------------------------------
-- Initialization
--

function mod:OnBossEnable()
	self:RegisterEvent("UPDATE_MOUSEOVER_UNIT")
	self:RegisterEvent("PLAYER_TARGET_CHANGED")
	self:Emote("Doors", L["door_trigger"])

	self:Log("SPELL_CAST_START", "VenomBoltVolley", 136587) --Venom Priests
	self:Log("SPELL_CAST_START", "SandTrap", 136725) --Wastewalker
	self:Log("SPELL_CAST_START", "BlazingSunlight", 136719) --Wastewalker
	self:Log("SPELL_CAST_START", "FrozenOrb", 136564) --Frozen Warlord
	self:Log("SPELL_CAST_SUCCESS", "Swipe", 136463)--Warbear
	self:Log("SPELL_CAST_START", "ChainLightning", 136480) --Beast Shaman
	
	self:Death("Disable", 68476)
end

function mod:OnEngage()
	counter = 1
	wipe(adds)
	self:RegisterEvent("PLAYER_REGEN_ENABLED", "CheckForWipe")
end

--------------------------------------------------------------------------------
-- Event Handlers
--

local function mark(mobId, counter)
	if not mod:LFR() then
		SetRaidTarget(mobId, counter)
	end
end

function mod:Doors()
	wipe(adds)
	counter = 1
end

function mod:UPDATE_MOUSEOVER_UNIT()
	local GUID = UnitGUID("mouseover")
	if not GUID then return end
	if mobs[self:MobId(GUID)] then
		if adds[GUID] ~= "marked" then
			adds[GUID] = "marked"
			mark("mouseover", counter)
			counter = counter + 1
		end
		if counter > 6 then counter = 1 end
	end
end

function mod:PLAYER_TARGET_CHANGED()
	local GUID = UnitGUID("target")
	if not GUID then return end
	if mobs[self:MobId(GUID)] then
		if adds[GUID] ~= "marked" then
			adds[GUID] = "marked"
			mark("target", counter)
			counter = counter + 1
		end
		if counter > 6 then counter = 1 end
	end
end

do
	local f = CreateFrame("Frame")
	local total = 0
	f:SetScript("OnUpdate", function(self, elapsed)
		total = total + elapsed
		if total > 0.2 then
			for guid in pairs(adds) do
				local mobId = mod:GetUnitIdByGUID(guid)
				if mobId then
					if adds[guid] ~= "marked" then
						adds[guid] = "marked"
						mark(mobId, counter)
						counter = counter + 1
					end
				end
			end
			if counter > 6 then counter = 1 end
			if not next(adds) then
				self:Hide()
			end
			total = 0
		end
	end)
	f:Hide()

	function mod:VenomBoltVolley(args)
		if self:MobId(args.sourceGUID) == 69164 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
	
	function mod:SandTrap(args)
		if self:MobId(args.sourceGUID) == 69175 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
	
	function mod:BlazingSunlight(args)
		if self:MobId(args.sourceGUID) == 69175 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
	
	function mod:FrozenOrb(args)
		if self:MobId(args.sourceGUID) == 69178 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
	
	function mod:Swipe(args)
		if self:MobId(args.sourceGUID) == 69177 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
	
	function mod:ChainLightning(args)
		if self:MobId(args.sourceGUID) == 69176 then
			if not adds[args.sourceGUID] then
				adds[args.sourceGUID] = true
				f:Show()
			end
		end
	end
end
